<?php
defined('ABSPATH') or die();
/* 
 * Plugin Name: WordPress Widget Style Editor Elementor Addon
 * Plugin URI: http://themegum.com/
 * Description: Styles maker for WordPress Sidebar Widget on Elementor widget modules: Archives, Categories, Tag Cloud, Recent Posts, Meta, Recent Comments, Search, Navigation Menu, Calendar, Pages
 * Version: 1.0.0
 * Author: TemeGUM
 * Author URI: http://themegum.com
 * Domain Path: /languages/
 * Text Domain: widget-styler-for-elementor
 */

final class Widget_Styler_Elementor_Addon{

  private static $_instance = null;

  public static function instance() {

    if ( is_null( self::$_instance ) ) {
      self::$_instance = new self();
    }
    return self::$_instance;

  }

	public function __construct() {

        define('WIDGET_STYLER_ELEMENTOR_URL', trailingslashit(plugin_dir_url( __FILE__ )));
        define('WIDGET_STYLER_ELEMENTOR_DIR', plugin_dir_path(__FILE__));


        load_plugin_textdomain('widget-styler-for-elementor', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');

        if(!function_exists('is_plugin_active')){
      		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
      	}


      	if(is_plugin_active('elementor/elementor.php')){
                   
      			add_action('init', array($this,'init'),999);
      	}
      	else{
      			add_action( 'admin_notices', array( $this, 'deactive_notice'), 10 );
	      		$this->deactive();
      	}

	}

	public function init(){

      add_action( 'elementor/elements/categories_registered', array( $this, '_register_elementor_category' ) );
      add_action( 'elementor/widgets/widgets_registered', array($this, '_elementor_widget_register') );
	}

  public function _register_elementor_category($manager){

    $manager->add_category('temegum', [
          'title' => 'TemeGUM',
          'icon' => 'eicon-font',
        ]);

    return $manager;

  }

  public function _elementor_widget_register(){

      if(defined('ELEMENTOR_PATH') && class_exists('Elementor\Widget_Base')){

        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_meta.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_tags.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_archive.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_posts.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_comments.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_search.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_calendar.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_categories.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_pages.php" );
        require_once( WIDGET_STYLER_ELEMENTOR_DIR."widgets/wp_menus.php" );
      }

  }

	function deactive_notice(){

		echo "<div class='error'>" .  esc_html__( 'WordPress Widget Style Editor Elementor Addon deactivated. The plugin need Elementor plugin, please install the plugin first.' ,'widget-styler-for-elementor'). "</div>";

	}

	function deactive(){
		deactivate_plugins( array('widget_styler_for_elementor/widget_styler_for_elementor.php'), true, is_network_admin() );
	}

}

Widget_Styler_Elementor_Addon::instance();