<?php
namespace Elementor;

/**
 * @package     WordPress
 * @subpackage  WordPress Widget Styler Elementor Addon
 * @author      support@themegum.com
 * @since       1.0.0
*/

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}



use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;

/**
 * WP Calendar widget.
 *
 * Widget_WordPress
 * @since 1.0.0
 */

class WP_Widget_Calendar_Style extends Widget_Base {

  /**
   * Get widget name.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'wp-widget-calendar-style';
  }

  /**
   * Get widget title.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Calendar', 'widget-styler-for-elementor' );
  }

  /**
   * Get widget icon.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-wordpress';
  }

  /**
   * Get widget categories.
   *
   * Retrieve the list of categories the button widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * @since 2.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [  'temegum' ];
  }

  public function get_keywords() {
    return [ 'wordpress', 'widget' ];
  }


  /**
   * Register button widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function _register_controls() {


    $this->start_controls_section(
      'section_content',
      [
        'label' => esc_html__( 'Content', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'title',
      [
        'label' => esc_html__( 'Title:', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'dynamic' => [
          'active' => false,
        ],
        'placeholder' => esc_html__( 'Enter widget title', 'widget-styler-for-elementor' ),
      ]
    );


    $this->add_control(
      'widget_title_size',
      [
        'label' => esc_html__( 'HTML Tag', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          'h2' => 'H2',
          'h3' => 'H3',
          'h4' => 'H4',
          'h5' => 'H5',
          'h6' => 'H6',
          'div' => 'div'
        ],
        'default' => 'h2',
      ]
    );


    $this->add_responsive_control(
      'text_align',
      [
        'label' => esc_html__( 'Alignment', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          '' => [
            'title' => esc_html__( 'Default', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-default',
          ],
          'left' => [
            'title' => esc_html__( 'Left', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-right',
          ],
          'justify' => [
            'title' => esc_html__( 'Justified', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-justify',
          ],
        ],
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'text-align: {{VALUE}};',
        ],
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'widget_title_styles',
      [
        'label' => esc_html__( 'Title', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_title_typography',
        'selector' => '{{WRAPPER}} .widgettitle',
      ]
    );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'widget_title_shadow',
        'selector' => '{{WRAPPER}} .widgettitle',
      ]
    );


    $this->add_control(
      'widget_title_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_title_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'background-color: {{VALUE}};',
        ],
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_title_border',
        'selector' => '{{WRAPPER}} .widget .widgettitle',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_title_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .widgettitle' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_title_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

   $this->end_controls_section();


    $this->start_controls_section(
      'widget_calendar_title_styles',
      [
        'label' => esc_html__( 'Month Title', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_calendar_title_typography',
        'selector' => '{{WRAPPER}} table caption',
      ]
    );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'widget_calendar_title_shadow',
        'selector' => '{{WRAPPER}} table caption',
      ]
    );


    $this->add_control(
      'widget_calendar_title_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} table caption' => 'color: {{VALUE}};',
        ],
      ]
    );

   $this->end_controls_section();

   $this->start_controls_section(
      'widget_calendar_week_styles',
      [
        'label' => esc_html__( 'Week Day', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_responsive_control(
      'widget_calendar_week_space',
      [
        'label' => esc_html__( 'Spacing', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'rem' => [
            'min' => 0,
            'max' => 100,
            'step'=> 1
          ],
        ],
        'default'=>['size'=>5],
        'selectors' => [
          '{{WRAPPER}} table caption' => 'margin-bottom: {{SIZE}}{{UNIT}};',
        ],
        'separator' => 'after',
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_calendar_week_typography',
        'selector' => '{{WRAPPER}} thead th',
      ]
    );


    $this->add_control(
      'widget_calendar_week_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} thead th' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_calendar_week_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} thead th' => 'background-color: {{VALUE}};',
        ]
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_calendar_week_border',
        'selector' => '{{WRAPPER}} thead th',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_calendar_week_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} thead th' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_calendar_week_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} thead th' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

   $this->end_controls_section();

   $this->start_controls_section(
      'widget_calendar_date_styles',
      [
        'label' => esc_html__( 'Calendar', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_calendar_date_typography',
        'selector' => '{{WRAPPER}} tbody td',
      ]
    );

    $this->add_control(
      'widget_calendar_date_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tbody td' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_calendar_date_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tbody td' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'widget_calendar_date_pad_bgcolor',
      [
        'label' => esc_html__( 'Empty Date Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tbody td.pad' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_calendar_date_border',
        'selector' => '{{WRAPPER}} tbody td',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_calendar_date_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} tbody td,{{WRAPPER}} tbody td a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_calendar_date_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} tbody td' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );


    $this->add_control(
      'widget_calendar_date_title',
      [
        'label' => esc_html__( 'Active Date', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before',
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_calendar_adate_typography',
        'selector' => '{{WRAPPER}} tbody td a',
      ]
    );


    $this->start_controls_tabs( 'widget_calendar_adate_styles' );

    $this->start_controls_tab(
      'widget_calendar_adate_style',
      [
        'label' => esc_html__( 'Normal', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'widget_calendar_adate_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tbody td a' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_calendar_adate_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tbody td a' => 'background-color: {{VALUE}};display:block;',
        ]
      ]
    );


    $this->end_controls_tab();
    $this->start_controls_tab(
      'widget_calendar_adate_hover_style',
      [
        'label' => esc_html__( 'Hover', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'widget_calendar_adate_hover_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tbody td a:hover' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_calendar_adate_hover_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tbody td a:hover' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->end_controls_tab();
    $this->end_controls_tabs();

    $this->end_controls_section();
    $this->start_controls_section(
      'widget_calendar_pagination_styles',
      [
        'label' => esc_html__( 'Navigation', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_responsive_control(
      'widget_pagination_space',
      [
        'label' => esc_html__( 'Spacing', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
            'step'=> 1
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} tfoot td' => 'padding: {{SIZE}}{{UNIT}} 0 0 0;',
          '{{WRAPPER}} nav' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_calendar_nav_typography',
        'selector' => '{{WRAPPER}} tfoot a,{{WRAPPER}} nav a',
        'separator' => 'before',
      ]
    );

    $this->start_controls_tabs( 'widget_calendar_nav_styles' );

    $this->start_controls_tab(
      'widget_calendar_nav_style',
      [
        'label' => esc_html__( 'Normal', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'widget_calendar_nav_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tfoot a,{{WRAPPER}} nav a' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_calendar_nav_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tfoot td:NOT(.pad) a' => 'background-color: {{VALUE}};display:block;',
          '{{WRAPPER}} nav span:NOT(.pad) a' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->end_controls_tab();
    $this->start_controls_tab(
      'widget_calendar_nav_hover_style',
      [
        'label' => esc_html__( 'Hover', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'widget_calendar_nav_hover_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tfoot td:NOT(.pad):hover a,{{WRAPPER}} nav span:NOT(.pad):hover a' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_calendar_nav_hover_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tfoot td:NOT(.pad):hover a,{{WRAPPER}} nav span:NOT(.pad):hover a' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'widget_calendar_nav_hover_bordercolor',
      [
        'label' => esc_html__( 'Border', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} tfoot td:NOT(.pad):hover a,{{WRAPPER}} nav span:NOT(.pad):hover a' => 'border-color: {{VALUE}};',
        ],
        'condition' => [
          'widget_calendar_nav_border_border!' => '',
        ],

      ]
    );


    $this->end_controls_tab();
    $this->end_controls_tabs();



    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_calendar_nav_border',
        'selector' => '{{WRAPPER}} tfoot td:NOT(.pad) a,{{WRAPPER}} nav span:NOT(.pad) a',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_calendar_nav_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} tfoot td:NOT(.pad) a,{{WRAPPER}} nav span:NOT(.pad) a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_calendar_nav_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} tfoot td:NOT(.pad) a,{{WRAPPER}} nav span:NOT(.pad) a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );


    $this->end_controls_section();
  

    $this->start_controls_section(
        'widget_content_styles',
        [
          'label' => esc_html__( 'Widget Body', 'widget-styler-for-elementor' ),
          'tab' => Controls_Manager::TAB_STYLE,
        ]
      );


      $this->add_control(
        'widget_content_bgcolor',
        [
          'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
          'type' =>  Controls_Manager::COLOR,
          'default' => '',
          'selectors' => [
            '{{WRAPPER}} .widget .calendar_wrap' => 'background-color: {{VALUE}};',
          ],
        ]
      );



      $this->add_responsive_control(
        'widget_content_space',
        [
          'label' => esc_html__( 'Spacing with Title', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::SLIDER,
          'range' => [
            'px' => [
              'min' => 0,
              'max' => 200,
              'step'=> 1
            ],
          ],
          'default'=>['size'=>0],
          'selectors' => [
            '{{WRAPPER}} .widget .calendar_wrap' => 'margin-top: {{SIZE}}{{UNIT}};',
            '{{WRAPPER}} .widgettitle' => 'margin-bottom: 0px;',
          ],
        ]
      );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_content_border',
        'selector' => '{{WRAPPER}} .widget .calendar_wrap',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_content_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .calendar_wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
        'widget_content_padding',
        [
          'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::DIMENSIONS,
          'size_units' => [ 'px', 'em', '%' ],
          'selectors' => [
            '{{WRAPPER}} .widget .calendar_wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          ],
          'separator' => 'before',
        ]
      );



    $this->end_controls_section();
  }

  /**
   * Render button widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    $widget_id = $this->get_id_int();

    $before_title = sprintf( '<%s class="widgettitle">', $settings['widget_title_size']); 
    $after_title = sprintf( '</%s>', $settings['widget_title_size']);

    the_widget( 'WP_Widget_Calendar', $settings, array( 'widget_id'=>"widget-".$widget_id, 'before_title' => $before_title, 'after_title' => $after_title ) );

  }

    /**
   * Render  output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 2.9.0
   * @access protected
   */
  protected function content_template() {

  }


}

// Registering widget

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new WP_Widget_Calendar_Style() );
?>
