<?php
namespace Elementor;

/**
 * @package     WordPress
 * @subpackage  WordPress Widget Styler Elementor Addon
 * @author      support@themegum.com
 * @since       1.0.0
*/

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}



use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;

/**
 * WP Recent Post widget.
 *
 * Widget_WordPress
 * @since 1.0.0
 */

class WP_Widget_Recent_Posts_Style extends Widget_Base {

  /**
   * Get widget name.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'wp-widget-recent-post-style';
  }

  /**
   * Get widget title.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Recent Posts', 'widget-styler-for-elementor' );
  }

  /**
   * Get widget icon.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-wordpress';
  }

  /**
   * Get widget categories.
   *
   * Retrieve the list of categories the button widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * @since 2.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [  'temegum' ];
  }

  public function get_keywords() {
    return [ 'wordpress', 'widget' ];
  }


  /**
   * Register button widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function _register_controls() {


    $this->start_controls_section(
      'section_content',
      [
        'label' => esc_html__( 'Content', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'title',
      [
        'label' => esc_html__( 'Title:', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'dynamic' => [
          'active' => false,
        ],
        'placeholder' => esc_html__( 'Enter widget title', 'widget-styler-for-elementor' ),
      ]
    );


    $this->add_control(
      'widget_title_size',
      [
        'label' => esc_html__( 'HTML Tag', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          'h2' => 'H2',
          'h3' => 'H3',
          'h4' => 'H4',
          'h5' => 'H5',
          'h6' => 'H6',
          'div' => 'div'
        ],
        'default' => 'h2',
      ]
    );


    $this->add_responsive_control(
      'text_align',
      [
        'label' => esc_html__( 'Alignment', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          '' => [
            'title' => esc_html__( 'Default', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-default',
          ],
          'left' => [
            'title' => esc_html__( 'Left', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-right',
          ],
          'justify' => [
            'title' => esc_html__( 'Justified', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-justify',
          ],
        ],
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'text-align: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'number',
      [
        'label' => esc_html__( 'Number of posts to show:', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::NUMBER,
        'default' => 5,
        'dynamic' => [
          'active' => false,
        ],
      ]
    );


    $this->add_control(
      'show_date',
      [
        'label' => esc_html__( 'Display post date?', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SWITCHER,
        'label_off' => esc_html__( 'No', 'widget-styler-for-elementor' ),
        'label_on' => esc_html__( 'Yes', 'widget-styler-for-elementor' ),
        'default' => '',
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'widget_title_styles',
      [
        'label' => esc_html__( 'Title', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_title_typography',
        'selector' => '{{WRAPPER}} .widgettitle',
      ]
    );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'widget_title_shadow',
        'selector' => '{{WRAPPER}} .widgettitle',
      ]
    );


    $this->add_control(
      'widget_title_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_title_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'background-color: {{VALUE}};',
        ],
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_title_border',
        'selector' => '{{WRAPPER}} .widget .widgettitle',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_title_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .widgettitle' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_title_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

   $this->end_controls_section();
  
   $this->start_controls_section(
      'widget_lists_styles',
      [
        'label' => esc_html__( 'Post Item', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );



    $this->add_control(
      'list_style',
      [
        'label' => esc_html__( 'List Style', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          '' => esc_html__( 'Deafult', 'widget-styler-for-elementor' ),
          'none' => esc_html__( 'None', 'widget-styler-for-elementor' ),
          'disc' => esc_html__( 'Disc', 'widget-styler-for-elementor' ),
          'circle' => esc_html__( 'Circle', 'widget-styler-for-elementor' ),
          'square' => esc_html__( 'Square', 'widget-styler-for-elementor' ),
        ],
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget ul' => 'list-style: {{VALUE}};',
        ],
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'label' => esc_html__( 'Post Typography', 'widget-styler-for-elementor' ),
        'name' => 'widget_content_typography',
        'selector' => '{{WRAPPER}} .widget ul a',
      ]
    );


    $this->add_responsive_control(
      'widget_list_space',
      [
        'label' => esc_html__( 'Spacing', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'rem' => [
            'min' => 0,
            'max' => 100,
            'step'=> 1
          ],
        ],
        'default'=>['size'=>5],
        'selectors' => [
          '{{WRAPPER}} .widget  ul > li' => 'margin-top: 0px;margin-bottom: {{SIZE}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->start_controls_tabs( 'widget_list_styles' );

    $this->start_controls_tab(
      'widget_list_style',
      [
        'label' => esc_html__( 'Normal', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'widget_list_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget ul a' => 'color: {{VALUE}};',
          '{{WRAPPER}} .widget ul > li' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_list_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget ul > li ' => 'background-color: {{VALUE}};',
        ]
      ]
    );

    $this->end_controls_tab();
    $this->start_controls_tab(
      'widget_list_hover_style',
      [
        'label' => esc_html__( 'Hover', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'widget_list_hover_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .widget li:hover,{{WRAPPER}} .widget li a:hover,{{WRAPPER}} .widget li:hover > a' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'widget_list_hover_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .widget ul > li:hover ' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'widget_list_border_hover_color',
      [
        'label' => esc_html__( 'Border', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .widget ul > li:hover' => 'border-color: {{VALUE}};',
        ],
        'condition' => [
          'widget_list_border_border!' => '',
        ],
      ]
    );


    $this->end_controls_tab();
    $this->end_controls_tabs();


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_list_border',
        'selector' => '{{WRAPPER}} .widget ul > li',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_list_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget ul > li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_list_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget ul > li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
        'widget_post_date_styles',
        [
          'label' => esc_html__( 'Post Date', 'widget-styler-for-elementor' ),
          'tab' => Controls_Manager::TAB_STYLE,
          'condition' => [
            'show_date!' => '',
          ],
        ]
      );


    $this->add_control(
      'widget_date_view',
      [
        'label' => esc_html__( 'Position', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'default' => '',
        'options' => [
          '' => [
            'title' => esc_html__( 'Default', 'widget-styler-for-elementor' ),
            'icon' => '',
          ],
          'inline' => [
            'title' => esc_html__( 'Inline', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-ellipsis-h',
          ],
          'block' => [
            'title' => esc_html__( 'New Row', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-ellipsis-v',
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .widget li .post-date' => 'display: {{VALUE}};',
        ],
      ]
    );


      $this->add_responsive_control(
        'widget_date_space_top',
        [
          'label' => esc_html__( 'Spacing', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::SLIDER,
          'range' => [
            'px' => [
              'min' => 0,
              'max' => 200,
              'step'=> 1
            ],
          ],
          'selectors' => [
            '{{WRAPPER}} .widget li .post-date' => 'margin-top: {{SIZE}}{{UNIT}};',
          ],
          'condition' => [
            'widget_date_view' => 'block',
          ],
        ]
      );


      $this->add_responsive_control(
        'widget_date_space_left',
        [
          'label' => esc_html__( 'Spacing', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::SLIDER,
          'range' => [
            'px' => [
              'min' => 0,
              'max' => 200,
              'step'=> 1
            ],
          ],
          'selectors' => [
            '{{WRAPPER}} .widget li > a' => 'margin-right: {{SIZE}}{{UNIT}};',
          ],
          'condition' => [
            'widget_date_view!' => 'block',
          ],
        ]
      );



    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_date_typography',
        'selector' => '{{WRAPPER}} .widget li .post-date',
      ]
    );


    $this->add_control(
      'widget_list_date_color',
      [
        'label' => esc_html__( 'Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget li .post-date' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_list_date_hovercolor',
      [
        'label' => esc_html__( 'Hover Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget li:hover > .post-date' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->end_controls_section();


    $this->start_controls_section(
        'widget_content_styles',
        [
          'label' => esc_html__( 'Widget Body', 'widget-styler-for-elementor' ),
          'tab' => Controls_Manager::TAB_STYLE,
        ]
      );


      $this->add_control(
        'widget_content_bgcolor',
        [
          'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
          'type' =>  Controls_Manager::COLOR,
          'default' => '',
          'selectors' => [
            '{{WRAPPER}} .widget .widget-body' => 'background-color: {{VALUE}};',
          ],
        ]
      );

      $this->add_responsive_control(
        'widget_content_space',
        [
          'label' => esc_html__( 'Spacing with Title', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::SLIDER,
          'range' => [
            'px' => [
              'min' => 0,
              'max' => 200,
              'step'=> 1
            ],
          ],
          'default'=>['size'=>0],
          'selectors' => [
            '{{WRAPPER}} .widget .widget-body' => 'margin-top: {{SIZE}}{{UNIT}};',
            '{{WRAPPER}} .widgettitle' => 'margin-bottom: 0px;',
          ],
        ]
      );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_content_border',
        'selector' => '{{WRAPPER}} .widget .widget-body',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_content_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .widget-body' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
        'widget_content_padding',
        [
          'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::DIMENSIONS,
          'size_units' => [ 'px', 'em', '%' ],
          'selectors' => [
            '{{WRAPPER}} .widget .widget-body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          ],
          'separator' => 'before',
        ]
      );



    $this->end_controls_section();
  }

  /**
   * Render button widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    $widget_id = $this->get_id_int();

    $before_title = sprintf( '<%s class="widgettitle">', $settings['widget_title_size']); 
    $after_title = sprintf( '</%s>', $settings['widget_title_size']).'<div class="widget-body">'; 

    the_widget( 'WP_Widget_Recent_Posts', $settings, array( 'widget_id'=>"widget-".$widget_id, 'before_title' => $before_title, 'after_title' => $after_title, 'after_widget' => '</div></div>') );

  }

    /**
   * Render  output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 2.9.0
   * @access protected
   */
  protected function content_template() {

  }


}

// Registering widget

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new WP_Widget_Recent_Posts_Style() );
?>
