<?php
namespace Elementor;

/**
 * @package     WordPress
 * @subpackage  WordPress Widget Styler Elementor Addon
 * @author      support@themegum.com
 * @since       1.0.0
*/

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}



use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;

/**
 * WP Search widget.
 *
 * Widget_WordPress
 * @since 1.0.0
 */

class WP_Widget_Search_Style extends Widget_Base {

  /**
   * Get widget name.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'wp-widget-search-style';
  }

  /**
   * Get widget title.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Search', 'widget-styler-for-elementor' );
  }

  /**
   * Get widget icon.
   *
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-wordpress';
  }

  /**
   * Get widget categories.
   *
   * Retrieve the list of categories the button widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * @since 2.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [  'temegum' ];
  }

  public function get_keywords() {
    return [ 'wordpress', 'widget' ];
  }


  /**
   * Register button widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function _register_controls() {


    $this->start_controls_section(
      'section_content',
      [
        'label' => esc_html__( 'Content', 'widget-styler-for-elementor' ),
      ]
    );

    $this->add_control(
      'title',
      [
        'label' => esc_html__( 'Title:', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'dynamic' => [
          'active' => false,
        ],
        'placeholder' => esc_html__( 'Enter widget title', 'widget-styler-for-elementor' ),
      ]
    );


    $this->add_control(
      'widget_title_size',
      [
        'label' => esc_html__( 'HTML Tag', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          'h2' => 'H2',
          'h3' => 'H3',
          'h4' => 'H4',
          'h5' => 'H5',
          'h6' => 'H6',
          'div' => 'div'
        ],
        'default' => 'h2',
      ]
    );


    $this->add_responsive_control(
      'text_align',
      [
        'label' => esc_html__( 'Alignment', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'options' => [
          '' => [
            'title' => esc_html__( 'Default', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-default',
          ],
          'left' => [
            'title' => esc_html__( 'Left', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-right',
          ],
          'justify' => [
            'title' => esc_html__( 'Justified', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-text-align-justify',
          ],
        ],
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'text-align: {{VALUE}};',
        ],
      ]
    );



    $this->add_control(
      'widget_search_form_view',
      [
        'label' => esc_html__( 'View', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::CHOOSE,
        'default' => 'block',
        'options' => [
          'inline' => [
            'title' => esc_html__( 'Row', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-ellipsis-h',
          ],
          'block' => [
            'title' => esc_html__( 'Column', 'widget-styler-for-elementor' ),
            'icon' => 'eicon-ellipsis-v',
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]' => 'display: {{VALUE}};',
        ],
        'separator' => 'before'
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'widget_title_styles',
      [
        'label' => esc_html__( 'Title', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_title_typography',
        'selector' => '{{WRAPPER}} .widgettitle',
      ]
    );


    $this->add_group_control(
      Group_Control_Text_Shadow::get_type(),
      [
        'name' => 'widget_title_shadow',
        'selector' => '{{WRAPPER}} .widgettitle',
      ]
    );


    $this->add_control(
      'widget_title_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_title_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'background-color: {{VALUE}};',
        ],
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_title_border',
        'selector' => '{{WRAPPER}} .widget .widgettitle',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_title_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .widgettitle' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_title_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widgettitle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

   $this->end_controls_section();

   $this->start_controls_section(
      'widget_search_input_styles',
      [
        'label' => esc_html__( 'Input Field', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );


    $this->add_responsive_control(
      'widget_search_input_width',
      [
        'label' => esc_html__( 'Width', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'size_units' => [ 'px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
            'step'=> 1
          ],
          '%' => [
            'min' => 0,
            'max' => 100,
            'step'=> 1
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]' => 'width: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'widget_search_form_view' => 'block',
        ],
        'separator' => 'after',
      ]
    );


    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_search_input_typography',
        'selector' => '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]',
      ]
    );



    $this->add_control(
      'widget_search_input_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_search_input_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_search_input_border',
        'selector' => '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_search_input_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_search_input_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );


   $this->end_controls_section();
  
   $this->start_controls_section(
      'widget_search_button_styles',
      [
        'label' => esc_html__( 'Button', 'widget-styler-for-elementor' ),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );



    $this->add_responsive_control(
      'widget_search_button_width',
      [
        'label' => esc_html__( 'Width', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'size_units' => [ 'px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
            'step'=> 1
          ],
          '%' => [
            'min' => 0,
            'max' => 100,
            'step'=> 1
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]' => 'width: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'widget_search_form_view' => 'block',
        ],
        'separator' => 'after',
      ]
    );



    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'widget_search_button_typography',
        'selector' => '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]',
      ]
    );

    $this->add_responsive_control(
      'widget_search_button_space_top',
      [
        'label' => esc_html__( 'Spacing', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
            'step'=> 1
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'widget_search_form_view' => 'block',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_search_button_space_left',
      [
        'label' => esc_html__( 'Spacing', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
            'step'=> 1
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-field,{{WRAPPER}} .widget input[type="search"],{{WRAPPER}} .widget input[type="text"]' => 'margin-right: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'widget_search_form_view!' => 'block',
        ],
      ]
    );


    $this->start_controls_tabs( 'widget_list_styles' );

    $this->start_controls_tab(
      'widget_search_button_style',
      [
        'label' => esc_html__( 'Normal', 'widget-styler-for-elementor' ),
      ]
    );



    $this->add_control(
      'widget_search_button_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]' => 'color: {{VALUE}};',
        ],
      ]
    );


    $this->add_control(
      'widget_search_button_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]' => 'background-color: {{VALUE}};',
        ]
      ]
    );

    $this->end_controls_tab();
    $this->start_controls_tab(
      'widget_search_button_hover_style',
      [
        'label' => esc_html__( 'Hover', 'widget-styler-for-elementor' ),
      ]
    );



    $this->add_control(
      'widget_search_button_hover_color',
      [
        'label' => esc_html__( 'Text Color', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .widget li:hover,{{WRAPPER}} .widget li a:hover,{{WRAPPER}} .widget li:hover > a' => 'color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'widget_search_button_hover_bgcolor',
      [
        'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .widget ul > li:hover ' => 'background-color: {{VALUE}};',
        ]
      ]
    );


    $this->add_control(
      'widget_search_button_border_hover_color',
      [
        'label' => esc_html__( 'Border', 'widget-styler-for-elementor' ),
        'type' =>  Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .widget ul > li:hover' => 'border-color: {{VALUE}};',
        ],
        'condition' => [
          'widget_search_button_border!' => '',
        ],
      ]
    );


    $this->end_controls_tab();
    $this->end_controls_tabs();


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_search_button_border',
        'selector' => '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_search_button_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
      'widget_search_button_padding',
      [
        'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget .search-submit,{{WRAPPER}} .widget input[type="button"],{{WRAPPER}} .widget input[type="submit"]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
        'widget_content_styles',
        [
          'label' => esc_html__( 'Widget Body', 'widget-styler-for-elementor' ),
          'tab' => Controls_Manager::TAB_STYLE,
        ]
      );


      $this->add_control(
        'widget_content_bgcolor',
        [
          'label' => esc_html__( 'Background', 'widget-styler-for-elementor' ),
          'type' =>  Controls_Manager::COLOR,
          'default' => '',
          'selectors' => [
            '{{WRAPPER}} .widget form' => 'background-color: {{VALUE}};',
          ],
        ]
      );



      $this->add_responsive_control(
        'widget_content_space',
        [
          'label' => esc_html__( 'Spacing with Title', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::SLIDER,
          'range' => [
            'px' => [
              'min' => 0,
              'max' => 200,
              'step'=> 1
            ],
          ],
          'default'=>['size'=>0],
          'selectors' => [
            '{{WRAPPER}} .widget form' => 'margin-top: {{SIZE}}{{UNIT}};',
            '{{WRAPPER}} .widgettitle' => 'margin-bottom: 0px;',
          ],
        ]
      );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'widget_content_border',
        'selector' => '{{WRAPPER}} .widget form',
        'separator' => 'before',
      ]
    );

    $this->add_control(
      'widget_content_border_radius',
      [
        'label' => esc_html__( 'Border Radius', 'widget-styler-for-elementor' ),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => [ 'px', '%' ],
        'selectors' => [
          '{{WRAPPER}} .widget form' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );


    $this->add_responsive_control(
        'widget_content_padding',
        [
          'label' => esc_html__( 'Padding', 'widget-styler-for-elementor' ),
          'type' => Controls_Manager::DIMENSIONS,
          'size_units' => [ 'px', 'em', '%' ],
          'selectors' => [
            '{{WRAPPER}} .widget form' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          ],
          'separator' => 'before',
        ]
      );



    $this->end_controls_section();
  }

  /**
   * Render button widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    $widget_id = $this->get_id_int();

    $before_title = sprintf( '<%s class="widgettitle">', $settings['widget_title_size']); 
    $after_title = sprintf( '</%s>', $settings['widget_title_size']);

    the_widget( 'WP_Widget_Search', $settings, array( 'widget_id'=>"widget-".$widget_id, 'before_title' => $before_title, 'after_title' => $after_title ) );

  }

    /**
   * Render  output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 2.9.0
   * @access protected
   */
  protected function content_template() {

  }


}

// Registering widget

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new WP_Widget_Search_Style() );
?>
